Enum servo_url::Host
[−]
[src]
pub enum Host<S = String> {
Domain(S),
Ipv4(Ipv4Addr),
Ipv6(Ipv6Addr),
}The host name of an URL.
Variants
Domain(S)A DNS domain name, as '.' dot-separated labels. Non-ASCII labels are encoded in punycode per IDNA.
Ipv4(Ipv4Addr)An IPv4 address.
Url::host_str returns the serialization of this address,
as four decimal integers separated by . dots.
Ipv6(Ipv6Addr)An IPv6 address.
Url::host_str returns the serialization of that address between [ and ] brackets,
in the format per RFC 5952 A Recommendation
for IPv6 Address Text Representation:
lowercase hexadecimal with maximal :: compression.
Methods
impl<'a> Host<&'a str>[src]
pub fn to_owned(&self) -> Host<String>[src]
Return a copy of self that owns an allocated String but does not borrow an &Url.
impl Host<String>[src]
pub fn parse(input: &str) -> Result<Host<String>, ParseError>[src]
Parse a host: either an IPv6 address in [] square brackets, or a domain.